
/*===============================================================================================================================
                                                                          
        ARTICLE: The Disciplinary Role of Financial Statements: Evidence from Mergers and Acquisitions of Privately Held Targets                      
        AUTHOR: Ciao-Wei Chen                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		CODE1 merges M&A transactions downloaded from SDC with COMPUSTAT/CRSP.
		Get acquirers' accounting and stock price information and prepare dataset for hand collection.

 ===============================================================================================================================*/


libname chen 'C:\Users\ciachen\Desktop\SEC Disclosure and M&A\Sample';

/* Import data downloaded from SDC */

PROC IMPORT OUT= sample_all DATAFILE= "C:\Users\ciachen\Desktop\SEC Disclosure and M&A\Sample\sample_all.xlsx" 
     DBMS=xlsx REPLACE;
     GETNAMES=YES;
RUN;

* delete acquirers make multiple acquisitions in a year ;

data sample_all;
	set sample_all;
	ann_year = year(ann);
	if not missing(ann_year);
run;

proc sort data = sample_all; by ann_year acq_u_cusip; run;

proc means data = sample_all noprint;
	var dealvalue;
	by ann_year acq_u_cusip;
	output out = count mean = value;
run;

proc sql;
	create table clean as select
	a.*, b._FREQ_ as count
	from sample_all a, count b
	where a.ann_year = b.ann_year and a.acq_U_CUSIP = b.acq_u_cusip;
quit;

proc sort data = clean; by ann; run;

data clean;
	set clean;
	if count ne 1 then delete;
run;

* delete acquirers make another acquisition in the next three years ;

proc sort data = clean; by acq_u_cusip ann; run;

data clean1;
	set clean;
	endYear = ann_year + 3;
	if acq_u_cusip = lag(acq_u_cusip) & ann_year <= lag(endYear) then delete = 1;
	else delete = 0;
	drop count;
run;

proc sort data = clean1; by acq_u_cusip descending ann_year; run;

data clean1;
	set clean1;
	if acq_u_cusip = lag(acq_u_cusip) & lag(delete) = 1 then delete2 = 1;
	else delete2 = 0;
run;

proc sort data = clean1; by acq_u_cusip ann_year; run;

data clean2;
	set clean1;
	if delete = 1 then delete;
	if delete2 = 1 then delete;
	drop count delete delete2;
run;

* delete remaining public targets ;
* keep only private targets ;

data clean2;
	set clean2;
	if TRG_PUBLIC = 'Public' then delete;
run;

proc sort data = clean2; by acq_u_cusip ann_year; run;

proc sort data = clean2; by ann; run;

/* Merge SDC data with COMPUSTAT/CRSP using LINKTABLE and acquirer CUSIP (from SDC) */

proc sql;
	create table match1 as select
	a.*, b.gvkey, b.cusip, b.permno
	from clean2 a, chen.linktable b
	where a.acq_u_cusip = substr(b.cusip8,1,6);
quit;

proc sort data = permno nodup; by gvkey; run;

data match2;
	set permno match1;
run;

proc sort data = match2 nodup; by ann acq_name; run;

data match2;
	set match2;
	cusip6 = substr(cusip,1,6);
	if acq_u_cusip = cusip6 then flag = 0; 
	else flag = 1;
run;

data match3;
	set match2;
	where flag = 0;
run;

data chen.merge;
	set match3;
run;

/* dataset "merge" contains acquirers' gvkey and germno */

data merge1;
	set chen.merge;
	drop flag;
run;

proc sort data = merge1; by ann acq_name; run;

data merge1;
	set merge1;
	key = trim (ann || "_") || trim(gvkey);
run;

data acq;
	set merge1;
	key = trim (ann || "_") || trim(gvkey);
	pre_year = ann_year - 1;
	keep ann key acq_name dealvalue ann_year gvkey permno pre_year;
run;

/* get total assets and market value one quarter before announcement year */

%let wrds = wrds.wharton.upenn.edu 4016; 
options comamid=TCP remote=wrds; 
signon username=_prompt_;

rsubmit;

proc upload data = acq out = acq; run;

proc sql;
	create table acq_at as select
	a.*, b.fqtr, b.datadate, b.atq, b.prccq, b.cshoq, b.mkvaltq
	from acq a, comp.fundq b
	where a.gvkey = b.gvkey and a.pre_year <= year(b.datadate)<= a.ann_year;
quit;

proc download data = acq_at out = acq_at; run;

endrsubmit;

proc sort data = acq_at nodup; by key descending datadate; run;

data acq_at;
	set acq_at;
	mkt_val = prccq*cshoq;
	drop mkvaltq;
	if not missing(atq);
	if not missing(mkt_val);
	dist = abs(datadate - ann);
run;

proc sort; by key dist; run;

data acq_at;
	set acq_at;
	by key;
	if first.key then output;
run;

data acq_at;
	set acq_at;
	rel_size = (dealvalue/mkt_val)*100;
	drop prccq cshoq dist;
run;

proc sql;
	create table sample as select 
	a.*, b.atq, b.mkt_val, b.rel_size
	from merge1 a, acq_at b
	where a.key = b.key;
quit;

data chen.sample;
	set sample;
run;

proc sort data = sample nodup; by gvkey ann; run;

/* dataset "sample" has acquirers' total asset and market value one quarter before acquisition announcements */
/* dataset "sample" also has relative size calculated as deal value / market value */

/* delete deal value smaller than 1% of acquirers' market value */
data sample_1;
	set sample;
	if not missing(rel_size);
	if rel_size < 1 then delete;
run;

proc sort data = sample_1; by key ;run;

data sample_1;
	set sample_1;
	by key;
	if first.key then output;
run;

data chen.sample_collection;
	set sample_1;
run;

/* dataset "sample_collection" is used to hand collect data on Regulation S-X disclsoures */
/* Please see Section 2 of the paper and the Data Sheet for information about collecting the disclosure data */ 



