/*===============================================================================================================================
                                                                          
        ARTICLE: The Disciplinary Role of Financial Statements: Evidence from Mergers and Acquisitions of Privately Held Targets                      
        AUTHOR: Ciao-Wei Chen                  
        JOURNAL OF ACCOUNTING RESEARCH 

 		CODE2 is used to construct three of the main dependent variables and control variables. 

		The three main dependent variables include acquirer's three-day announcement returns,change in ROA, 
		and change in industry-adjuted ROR. 

		Control variables include TRESHOLD, square of THRESHOLD, cube of THRESHOLD, TRG_SIZE, ACQ_SIZE, profitability (ROA), 
		Tobin's Q, leverage, method of payment, and diversifying acquisitions. 

 ===============================================================================================================================*/

libname chen 'C:\Users\ciachen\Desktop\SEC Disclosure and M&A\Sample';

/* Import dataset "data" saved in SEC Disclosure and M&A\Sample */
/* This dataset contains hand collected disclosure data and deal characteristics */

PROC IMPORT OUT= data DATAFILE= "C:\Users\ciachen\Desktop\SEC Disclosure and M&A\Sample\data.xlsx" 
     DBMS=xlsx REPLACE;
     GETNAMES=YES;
RUN;

/* calculate control variables */
* acquirer characteristics: size, profitability, leverage, and Tobin's Q ;
* target size : log(dealvalue) ;
* threshold: dealvalue/at ;

data b;
	set data;
	preyear = year(ann) - 1;
run;

proc sort data = b; by key; run;

rsubmit;

proc upload data = b out = b; run;

proc sql;
	create table comp as select
	a.*, b.fyear, b.at, b.ceq, b.dlc, b.dltt, b.oibdp, b.csho, b.prcc_f
	from b a left join comp.funda b
	on a.gvkey = b.gvkey and a.preyear = b.fyear;
quit;

proc download data = comp out = compdata; run;

endrsubmit;

* calculate control variables ;

data controls;
	set compdata;
	if not missing(at);
	if not missing(ceq);
	if not missing(csho);
	size = log(csho*abs(prcc_f));
	lev = (dlc + dltt)/at;
	roa = oibdp/at;
	tobin = (at - ceq+csho*abs(prcc_f))/at;
	if percent_stock = 100 then stock = 1; else stock = 0;
	if percent_cash = 100 then cash = 1; else cash = 0;
	rel_size = dealvalue/size;
	threshold = dealvalue/at;
	threshold2 = threshold*threshold;
	threshold3 = threshold*threshold*threshold;
	trg_size = log(dealvalue);
	acq_sic2 = int(acq_sic/100);
	trg_sic2 = int(trg_sic/100);
	diffind = 1;
	if acq_sic2 = trg_sic2 then diffind = 0;
run;

data chen.controls; set controls; run;


/* Calculate acquirer three-day announcement returns */

/***********************************************************************
				3-day returns from market model
***********************************************************************/

* correct non-trading event dates ;
* use the previous trading date when the announcement date (t) is non-trading date ;
* use the previous trading date when t-1 is non-trading date ;
* use the next trading date when t+1 is non-trading date ;


data temp;
	set data;
	ann_year = year(ann);
run;

proc freq data = temp;
	table ann_year;
run;

proc sql;
	create table event as select
	a.*, b.caldt as eventdate
	from temp a, chen.crsp_day_cal_2013 b
	where a.ann = b.cal_date;
quit;

data event;
	set event;
	pre = intnx ('Day', eventdate, -1, 'B');
	next = intnx ('Day', eventdate, +1, 'B');
	format pre next date9.;
run;

proc sql;
	create table event1 as select
	a.*, b.caldt as nextday
	from event a, chen.crsp_day_cal_2013 b
	where a.next = b.cal_date;
quit;

proc sql;
	create table event2 as select
	a.*, b.caldt as preday
	from event1 a, main.crsp_day_cal_2013_prdt b
	where a.pre = b.cal_date;
quit;

data event2;
	set event2;
	label preday = preday;
	label nextday = nextday;
	label eventdate = eventday;
	drop pre next;
run;

*estimate market model parameters, alpha and beta ;

data event3;
	set event2;
	beg = intnx ('Day', eventdate, -200, 'B');
	end = intnx ('Day', eventdate, -60, 'B');
	format beg end date9.;
run;

rsubmit;

proc upload data = event3 out = event3; run;

proc sql;
	create table ret2 as select
	a.*, b.ret, b.date
	from event3 a left join crsp.dsf b
	on a.permno = b.permno and a.beg <= b.date <= a.end;

	create table ret2 as select
	a.*, b.ewretd, b.vwretd
	from ret2 a left join crsp.dsi b
	on a.date = b.date;
quit;

proc download data = ret2 out = ret2; run;

endrsubmit;

data ret2;
	set ret2;
	if not missing(ret);
	if (1*ret) = ret;
run;

proc sort data = ret2; by key date; run;

proc reg data = ret2 outest = beta;
	id key;
	model ret = vwretd / noprint;
	by key;
run;

data beta;
	set beta;
	alpha = intercept;
	beta = vwretd;
	keep key alpha beta;
run;

proc sql;
	create table ret_beta as select
	a.*, b.alpha, b.beta
	from ret a, beta b
	where a.key = b.key;
quit;

* calculate abnormal returns ;

data ret_beta;
	set ret_beta;
	ABR = ret - (alpha + beta*vwretd);
run; 

proc sort data = ret_beta; by key; run;

data car;
	set ret_beta;
	by key;
	retain counter car;
	if first.key then counter = 0;
	if first.key then car = 0;
	counter + 1;
	car = car + abr;
	if last.key then output;
run;

/* combine car and controls and winsorize */

proc sql;
	create table car
	as select a.*, b.size, b.lev, b.roa, b.tobin, b.threshold, b.threshold2, b.threshold3, b.trg_size, b.stock, b.cash, b.diffind
	from car a, controls b
	where a.key = b.key;
quit;

%macro winsor(inds,outds,var,pctiles);
%local low lowvar up upvar;
%let low=%scan(&pctiles,1,%str( ));
%if (%length(%scan(&low,2,.)) ne 0) %then %do;
%let lowvar=%scan(&low,1,.)_%scan(&low,2,.); %end;
%else %do;
%let lowvar=&low;
%end;
%let up =%scan(&pctiles,2,%str( ));
%if (%length(%scan(&up,2,.)) ne 0) %then %do;
%let upvar=%scan(&up,1,.)_%scan(&up,2,.); %end;
%else %do;
%let upvar=&up;
%end;
proc sort data=&inds;
by &var;
proc univariate noprint;
var &var;
output out=trim_ pctlpts= &low &up pctlpre=p;
data &outds (drop=p&lowvar p&upvar);
retain p&lowvar p&upvar;
if _n_=1 then set trim_ (keep=p&lowvar p&upvar);
else set &inds (in=ininds);
if &var LT p&lowvar then &var=p&lowvar;
else if &var GT p&upvar then &var=p&upvar;
if ininds then output;
run;
%mend winsor;

%winsor(car,car_win,car,1 99);
%winsor(car_win,car_win,size,1 99);
%winsor(car_win,car_win,lev,1 99);
%winsor(car_win,car_win,roa,1 99);
%winsor(car_win,car_win,tobin,1 99);
%winsor(car_win,car_win,threshold1,1 99);
%winsor(car_win,car_win,threshold2,1 99);
%winsor(car_win,car_win,threshold3,1 99);
%winsor(car_win,car_win,trg_size,1 99);

data chen.car; set car_win; run;


/***********************************************************************
						Change in ROA 
***********************************************************************/

data acq;
	set temp;
	keep ann eff acq_name acq_sic key gvkey permno trg_nation_code;
run;

/* get ROA data from compustat */

%let wrds=wrds.wharton.upenn.edu 4016;
options comamid=TCP remote=wrds;
signon username=_prompt_;

/* Average ROA in pre-acquisiton period */

rsubmit;

libname comp '/wrds/comp/sasdata/nam';

proc upload data = acq out = acq; run;

proc sql;
	create table compdata as select
	a.*, b.fyear, b.at, b.ib, b.xint, b.txt, b.pi
	from acq a left join comp.funda b
	on a.gvkey = b.gvkey and (year(a.eff)-3)<= b.fyear <= (year(a.eff)-1);
quit;

proc download data = compdata out = roa1; run;

endrsubmit;

/* adjust ROA for after-tax interest expense */

data preroa;
	set roa1;
	if (key = lag(key) and fyear = lag(fyear)) then delete;
	if xint = . then xint = 0;
	etr = txt/pi;
	if not missing(ib*at);
	preroa = (ib+etr*xint)/at;
run;

proc sort data = preroa nodup; by key; run;

proc means data = preroa noprint;
	var preroa;
	by key;
	output out = preroa1 mean = preroa;
run;	

/* Average ROA in post-acquisiton period */

rsubmit;

libname comp '/wrds/comp/sasdata/nam';

proc upload data = acq out = acq; run;

proc sql;
	create table compdata as select
	a.*, b.fyear, b.at, b.ib, b.xint, b.txt, b.pi
	from acq a left join comp.funda b
	on a.gvkey = b.gvkey and (year(a.eff)+ 1)<= b.fyear <= (year(a.eff)+3);
quit;

proc download data = compdata out = roa2; run;

endrsubmit;

/* adjust ROA for after-tax interest expense */

data postroa;
	set roa2;
	if (key = lag(key) and fyear = lag(fyear)) then delete;
	if xint = . then xint = 0;
	etr = txt/pi;
	if not missing(ib*at);
	postroa = (ib+etr*xint)/at;
run;

proc sort data = postroa nodup; by key; run;

proc means data = postroa noprint;
	var postroa;
	by key;
	output out = postroa1 mean = postroa;
run;

/* change in ROA is calculated as average post-ROA minus average pre-ROA */

proc sql;
	create table changeroa as select
	a.key, a.preroa, b.postroa, (b.postroa - a.preroa) as changeroa
	from preroa1 a, postroa1 b
	where a.key = b.key
	order by key;
quit;

/* combine changeroa and controls and winsorize */

proc sql;
	create table roa
	as select a.*, b.size, b.lev, b.roa, b.tobin, b.threshold, b.threshold2, b.threshold3, b.trg_size, b.stock, b.cash, b.diffind
	from changeroa a, controls b
	where a.key = b.key;
quit;

%winsor(roa,roa_win,changeroa,1 99);
%winsor(roa_win,roa_win,size,1 99);
%winsor(roa_win,roa_win,lev,1 99);
%winsor(roa_win,roa_win,roa,1 99);
%winsor(roa_win,roa_win,tobin,1 99);
%winsor(roa_win,roa_win,threshold1,1 99);
%winsor(roa_win,roa_win,threshold2,1 99);
%winsor(roa_win,roa_win,threshold3,1 99);
%winsor(roa_win,roa_win,trg_size,1 99);

data chen.roa; set roa_win; run;


/***********************************************************************
					Change in Industry-Adjusted ROA 
***********************************************************************/

/* calculate industry-adjusted ROA */

rsubmit;
libname comp '/wrds/comp/sasdata/nam';

proc sql;
	create table comp as select
	a.gvkey, a.fyear, a.sich, a.at, a.ib, a.xint, a.txt, a.pi
	from comp.funda a
	where 1990 <= a.fyear <= 2012 and a.at > 0;
quit;

proc download data = comp out = comp; run;

endrsubmit;

/* adjust ROA for after-tax interest expense */

data comp1;
	set comp;
	sic2 = int(sich/100);
	if xint = . then xint = 0;
	etr = txt/pi;
	roa = (ib+etr*xint)/at;
	if not missing(sic2*roa);
run;

/* calculate median ROA by year and 2-digit SIC industry */

proc sort data = comp1; by fyear sic2; run;

proc means data = comp1 noprint;
	var roa;
	by fyear sic2;
	output out = roa_med median = roa_med;
run;

/* calculate industry-adjusted ROA */

proc sql;
	create table roa_ind as select
	a.*, b.roa_med, (roa - roa_med) as roa_ind
	from comp1 a, roa_med b
	where a.fyear = b.fyear and a.sic2 = b.sic2;
quit;

proc sort data = roa_ind nodup; by gvkey; run;

/* pre-period indusry-adjusted ROA */

proc sql;
	create table r as select
	a.*, b.roa_ind, b.fyear
	from temp a, roa_ind b
	where a.gvkey = b.gvkey and (year(a.eff)-3) <= b.fyear <= (year(a.eff)-1);
quit;

proc sort data = r nodup; by key; run;

proc means data = r noprint;
	var roa_ind;
	by key;
	output out = r1 mean = preroa;
run;

/* post-period industry-adjusted ROA */

proc sql;
	create table r2 as select
	a.*, b.roa_ind, b.fyear
	from temp a, roa_ind b
	where a.gvkey = b.gvkey and (year(a.eff)+1) <= b.fyear <= (year(a.eff)+3);
quit;

proc sort data = r2 nodup; by key; run;

proc means data = r2 noprint;
	var roa_ind;
	by key;
	output out = r3 mean = postroa;
run;

/* change in industry-adjusted ROA is calculated as average post-ROA minus average pre-ROA */

proc sql;
	create table roa_i as select
	a.key, a.preroa, b.postroa, (postroa - preroa) as changeroa
	from r1 a, r3 b
	where a.key = b.key;
quit;

/* combine roa_i and controls and winsorize */

proc sql;
	create table roa_ind
	as select a.*, b.size, b.lev, b.roa, b.tobin, b.threshold, b.threshold2, b.threshold3, b.trg_size, b.stock, b.cash, b.diffind
	from roa_i a, controls b
	where a.key = b.key;
quit;

%winsor(roa_ind,roa_ind_win,changeroa,1 99);
%winsor(roa_ind_win,roa_ind_win,size,1 99);
%winsor(roa_ind_win,roa_ind_win,lev,1 99);
%winsor(roa_ind_win,roa_ind_win,roa,1 99);
%winsor(roa_ind_win,roa_ind_win,tobin,1 99);
%winsor(roa_ind_win,roa_ind_win,threshold1,1 99);
%winsor(roa_ind_win,roa_ind_win,threshold2,1 99);
%winsor(roa_ind_win,roa_ind_win,threshold3,1 99);
%winsor(roa_ind_win,roa_ind_win,trg_size,1 99);

data chen.roa_ind; set roa_ind_win; run;
